@@ -1,5 +1,4 @@
 import argparse
-import socket
 
 from .pycharm_remote_debugger import PycharmRemoteDebugger
 
@@ -14,12 +13,8 @@ def main():
                         default=PycharmRemoteDebugger.DEFAULT_CONNECTION_TIMEOUT)
 
     args = parser.parse_args()
-    try:
-        debugger = PycharmRemoteDebugger(args.remote, args.port)
-        debugger.wait_for_debugger(args.timeout)
-    except socket.timeout:
-        if not args.optional:
-            raise
+    debugger = PycharmRemoteDebugger(args.remote, args.port, args.optional)
+    debugger.wait_for_debugger(args.timeout)
 
 
 if __name__ == '__main__':
